#
# gene2ps.u133x3p.R
#
# Aron C. Eklund and Qiyuan Li
# 2010-04-17
#



gene2ps.u133x3p <- function(eg, symbol, alias, ensembl) {
  warn <- function(txt, things) {
    msg <- paste(txt, paste(things, collapse = ", "), sep = ": ")
    warning(msg, call. = FALSE)
  }
  if(sum(missing(eg), missing(symbol), missing(alias), missing(ensembl)) != 3) {
    stop("one of {eg, symbol, alias, ensembl} must be specified")
  }
  if(!missing(eg)) {  # eg was supplied
    eg <- as.character(eg)  # just in case
    nms <- eg
  }
  if(!missing(symbol)) {  # symbol was supplied
    nms <- symbol
    eg.list <- mget(symbol, org.Hs.egSYMBOL2EG, ifnotfound = list(NA))
    noAlias <- symbol[which(is.na(eg.list))]
    if(length(noAlias) > 0) {
      warn("the following symbol(s) are not recognized", noAlias)
    }
    ambiguous <- symbol[which(sapply(eg.list, length) > 1)]
    if(length(ambiguous) > 0) {
      warn("the following symbol(s) are ambiguous", ambiguous)
    }
    eg <- sapply(eg.list, function(x) if(length(x) == 1) x else NA)
  }
  if(!missing(alias)) {  # alias was supplied
    nms <- alias
    eg.list <- mget(alias, org.Hs.egALIAS2EG, ifnotfound = list(NA))
    noAlias <- alias[which(is.na(eg.list))]
    if(length(noAlias) > 0) {
      warn("the following alias(s) are not recognized", noAlias)
    }
    ambiguous <- alias[which(sapply(eg.list, length) > 1)]
    if(length(ambiguous) > 0) {
      warn("the following alias(s) are ambiguous", ambiguous)
    }
    eg <- sapply(eg.list, function(x) if(length(x) == 1) x else NA)
  }
  if(!missing(ensembl)) {  # ensembl was supplied
    nms <- ensembl
    eg.list <- mget(ensembl, org.Hs.egENSEMBL2EG, ifnotfound = list(NA))
    noAlias <- ensembl[which(is.na(eg.list))]
    if(length(noAlias) > 0) {
      warn("the following ensembl ID(s) are not recognized", noAlias)
    }
    ambiguous <- ensembl[which(sapply(eg.list, length) > 1)]
    if(length(ambiguous) > 0) {
      warn("the following ensembl ID(s) are ambiguous", ambiguous)
    }
    eg <- sapply(eg.list, function(x) if(length(x) == 1) x else NA)
  }
#  unknownEg <- setdiff(eg, c(NA, names(eg2ps.u133x3p)))
#  if(length(unknownEg) > 0) {
#    warn("the following Entrez GeneID(s) are not recognized", unknownEg)
#  }
  if (length(eg) == 1 && is.na(eg)) out <- NA
    else out <- eg2ps.u133x3p[eg]
#  noProbeset <- nms[is.na(out) & (eg %in% names(eg2ps.u133x3p))]
  noProbeset <- nms[is.na(out) & !is.na(eg)]
  if(length(noProbeset) > 0) {
    warn("no probe sets were found for the following", noProbeset)
  }
  names(out) <- nms
  out
}  

