\name{eg2ps}
\docType{data}
\alias{eg2ps.hgu95av2}
\alias{eg2ps.hgu133a}
\alias{eg2ps.hgu133plus2}
\alias{eg2ps.u133x3p}
\title{One-to-one map between Entrez GeneID and optimal probe set}
\description{
This data set provides a one-to-one mapping between human genes
and probe sets on Affymetrix human gene expression microarrays.}
\usage{eg2ps.hgu95av2}
\usage{eg2ps.hgu133a}
\usage{eg2ps.hgu133plus2}
\usage{eg2ps.u133x3p}
\details{
For a given gene of interest, Affymetrix microarrays often have several probe sets
interrogating the gene.  
This data can be used to choose a single probe set for a specified gene.

For each gene detected on the array, a single probe set is chosen 
to maximize specificity, transcript isoform coverage, 
and robustness against transcript degradation.
}
\format{A character vector. 
  The values are probe set IDs, and the names are Entrez GeneIDs.}
\source{
The \code{eg2ps.*} data objects are generated from the \code{\link[jetset]{scores}} objects with this function:
\preformatted{
  make.eg2ps <- function(scores) {
    a <- scores[order(scores$overall, decreasing = TRUE), ]
    a <- a[!duplicated(a$EntrezID) & !is.na(a$EntrezID),]
    a <- a[order(a$EntrezID), ]
    e <- rownames(a)
    names(e) <- a$EntrezID
    e
  }
}
}
\references{
Qiyuan Li, Nicolai Juul, Balazs Gyorffy, Zoltan Szallasi and Aron C. Eklund. \cr
Jetset: selecting an optimal microarray probe set to represent a gene.  \cr
Manuscript in preparation.
}
\note{
This data is also available in CSV format from
\url{http://www.cbs.dtu.dk/biotools/jetset/}
}
\seealso{ \code{\link[jetset]{gene2ps.hgu95av2}} for a convenience function.
}
\keyword{datasets}
