\name{gene2ps}
\alias{gene2ps.hgu95av2}
\alias{gene2ps.hgu133a}
\alias{gene2ps.hgu133plus2}
\alias{gene2ps.u133x3p}
\title{Retrieve the optimal probe sets for genes of interest}
\description{This ``convenience function'' retrieves the optimal
probe set IDs for one or more genes, using the jetset criteria.}
\usage{
gene2ps.hgu95av2(eg, symbol, alias, ensembl)
gene2ps.hgu133a(eg, symbol, alias, ensembl)
gene2ps.hgu133plus2(eg, symbol, alias, ensembl)
gene2ps.u133x3p(eg, symbol, alias, ensembl)
}
\arguments{
  \item{eg}{ A vector of Entrez GeneIDs (optional) }
  \item{symbol}{ A vector of gene symbols (optional) }
  \item{alias}{ A vector of gene aliases (optional) }
  \item{ensembl}{ A vector of Ensembl IDs (optional) }
}
\details{
Exactly one of \code{eg}, \code{symbol}, \code{alias}, or \code{ensembl} must be supplied.
The Entrez GeneID (\code{eg}) is the least ambiguous gene identifier, 
whereas the \code{alias} is the most ambiguous.

If the input is not recognized, or is ambiguous, or corresponds to a gene
that is not detected by the array, \code{NA} will be returned.
}
\value{A vector of probe set IDs}
\references{
Qiyuan Li, Nicolai Juul, Balazs Gyorffy, Zoltan Szallasi and Aron C. Eklund. \cr
Jetset: selecting an optimal microarray probe set to represent a gene.  \cr
Manuscript in preparation.
}
\seealso{The underlying data comes from \code{\link{eg2ps.hgu95av2}} (etc.),
with symbol and alias lookups coming from 
\code{\link{org.Hs.egSYMBOL2EG}} and \code{\link{org.Hs.egALIAS2EG}}.
}
\examples{
  genes <- c('MKI67', 'CHD5', 'ESR1', 'FGF19', 'ERBB2', 'NoSuchGene')

  # This generates several informative warnings
  gene2ps.hgu95av2(symbol = genes)

}
\keyword{ misc }
