\name{scores}
\docType{data}
\alias{scores.hgu95av2}
\alias{scores.hgu133a}
\alias{scores.hgu133plus2}
\alias{scores.u133x3p}
\title{Probe set quality scores}
\description{
This data set provides quality scores for each probe set on the 
corresponding Affymetrix gene expression microarrays.}
\usage{scores.hgu95av2}
\usage{scores.hgu133a}
\usage{scores.hgu133plus2}
\usage{scores.u133x3p}
\details{
If the majority of the probes in a probe set are specific 
for a single gene, this is defined as the \emph{targeted gene}. If no such majority exists, 
the targeted gene is \code{NA}, as are the following scores.

The \emph{processivity requirement} is the number of consecutive bases that
must be synthesized to generate a target that can be detected by the probe set.

The \emph{specificity score} is the fraction of the probes in a probe set 
that are likely to detect the targeted gene and unlikely to detect other genes.

The \emph{coverage score} is the fraction of the splice isoforms
belonging to the targeted gene that are detected by the probe set.

The \emph{robustness score} quantifies robustness against transcript
degradation.  The robustness score uses the processivity requirement to estimate the 
signal intensity of a probe set, relative to the ideal case of perfect processivity.

The \emph{overall score} is the product of the specificity score, 
coverage score, and robustness score.

All scores can range from 0 to 1.  A higher score indicates better (predicted) performance. 
}
\format{A data frame with 6 columns:
  \describe{
    \item{EntrezID}{Entrez GeneID of the targeted gene (character).}
    \item{process}{Processivity requirement  (integer).}
    \item{specificity}{Specificity score (numeric).}
    \item{coverage}{Coverage score (numeric).}
    \item{robust}{Robustness score (numeric).}
    \item{overall}{Overall score (numeric).}
  }
}
\source{Scores are calculated from BLASTN alignments between probe sequences
  and Refseq transcript sequences, as described in the reference below.}
\references{
Qiyuan Li, Nicolai Juul, Balazs Gyorffy, Zoltan Szallasi and Aron C. Eklund. \cr
Jetset: selecting an optimal microarray probe set to represent a gene.  \cr
Manuscript in preparation.
}
\note{
This data is also available in CSV format from
\url{http://www.cbs.dtu.dk/biotools/jetset/}
}
\seealso{ (e.g.) \code{\link[jetset]{gene2ps.hgu95av2}} }
\examples{
  ## Get the EntrezID for the ESR1 gene
  id <- get('ESR1', org.Hs.egSYMBOL2EG)
  
  ## Extract the scores for all probe sets detecting ESR1
  scores.hgu95av2[which(scores.hgu95av2$EntrezID == id), ]
}
\keyword{datasets}
